V0.2 coerce adapter runtime for the dactor actor framework.
Bridges dactor’s Actor/Handler<M>/ActorRef<A> API with coerce-rs’s
actor system using type-erased dispatch.
Structs
- Coerce
Actor Ref - A dactor
ActorRefbacked by a coerceLocalActorRef. - Coerce
Runtime - A dactor v0.2 runtime backed by coerce-rs.
- Coerce
System Actor Refs - References to the native coerce system actors spawned by the runtime.
- Spawn
Options - Options for spawning an actor, including the inbound interceptor pipeline.
Use
..Default::default()to future-proof against new fields.